@@ -23,12 +23,21 @@
 // Qt
 #include <QtGui/QFontMetrics>
 #include <QtCore/QFileInfo>
+#include <QCompleter>
+#include <QFileSystemModel>
+#include <QtCore/QUrl>
+#include <QtGui/QIcon>
 
 // KDE
-#include <KColorDialog>
+#include <QColorDialog>
 #include <KWindowSystem>
 #include <KFileDialog>
 #include <KUrlCompletion>
+#include <KLocalizedString>
+#include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QVBoxLayout>
 
 // Konsole
 #include "ui_ColorSchemeEditor.h"
@@ -39,52 +48,62 @@ using namespace Konsole;
 
 // colorTable is half the length of _table in ColorScheme class
 // since intense colors are in a separated column
-const int COLOR_TABLE_ROW_LENGTH =  TABLE_COLORS / 2; 
+const int COLOR_TABLE_ROW_LENGTH =  TABLE_COLORS / 2;
 
 const int NAME_COLUMN = 0;           // column 0 : color names
 const int COLOR_COLUMN = 1;          // column 1 : actual colors
 const int INTENSE_COLOR_COLUMN = 2;  // column 2 : intense colors
 
 ColorSchemeEditor::ColorSchemeEditor(QWidget* aParent)
-    : KDialog(aParent)
+    : QDialog(aParent)
     , _isNewScheme(false)
     , _colors(0)
 {
     // Kdialog buttons
-    setButtons(KDialog::Ok | KDialog::Cancel | KDialog::Apply);
-    connect(this, SIGNAL(applyClicked()), this, SLOT(saveColorScheme()));
-    connect(this, SIGNAL(okClicked()), this, SLOT(saveColorScheme()));
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel|QDialogButtonBox::Apply);
+    QWidget *mainWidget = new QWidget(this);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
+    mainLayout->addWidget(mainWidget);
+    QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setDefault(true);
+    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &ColorSchemeEditor::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &ColorSchemeEditor::reject);
+    mainLayout->addWidget(buttonBox);
+    connect(buttonBox->button(QDialogButtonBox::Apply), &QPushButton::clicked, this, &Konsole::ColorSchemeEditor::saveColorScheme);
+    connect(okButton, &QPushButton::clicked, this, &Konsole::ColorSchemeEditor::saveColorScheme);
 
     // ui
     _ui = new Ui::ColorSchemeEditor();
-    _ui->setupUi(mainWidget());
+    _ui->setupUi(mainWidget);
 
     // description edit
-    _ui->descriptionEdit->setClearButtonShown(true);
-    connect(_ui->descriptionEdit , SIGNAL(textChanged(QString)) , this ,
-            SLOT(setDescription(QString)));
+    _ui->descriptionEdit->setClearButtonEnabled(true);
+    connect(_ui->descriptionEdit , &QLineEdit::textChanged , this , &Konsole::ColorSchemeEditor::setDescription);
 
     // transparency slider
     QFontMetrics metrics(font());
     _ui->transparencyPercentLabel->setMinimumWidth(metrics.width("100%"));
 
-    connect(_ui->transparencySlider , SIGNAL(valueChanged(int)) , this , SLOT(setTransparencyPercentLabel(int)));
+    connect(_ui->transparencySlider , &QSlider::valueChanged , this , &Konsole::ColorSchemeEditor::setTransparencyPercentLabel);
 
     // randomized background
-    connect(_ui->randomizedBackgroundCheck , SIGNAL(toggled(bool)) , this ,
-            SLOT(setRandomizedBackgroundColor(bool)));
+    connect(_ui->randomizedBackgroundCheck , &QCheckBox::toggled , this , &Konsole::ColorSchemeEditor::setRandomizedBackgroundColor);
 
     // wallpaper stuff
-    KUrlCompletion* fileCompletion = new KUrlCompletion(KUrlCompletion::FileCompletion);
-    fileCompletion->setParent(this);
-    _ui->wallpaperPath->setCompletionObject(fileCompletion);
-    _ui->wallpaperPath->setClearButtonShown(true);
-    _ui->wallpaperSelectButton->setIcon(KIcon("image-x-generic"));
+    QFileSystemModel *dirModel = new QFileSystemModel(this);
+    dirModel->setFilter(QDir::AllEntries);
+    dirModel->setRootPath(QString('/'));
+    QCompleter *completer = new QCompleter(this);
+    completer->setModel(dirModel);
+    _ui->wallpaperPath->setCompleter(completer);
 
-    connect(_ui->wallpaperSelectButton, SIGNAL(clicked()),
-            this, SLOT(selectWallpaper()));
-    connect(_ui->wallpaperPath, SIGNAL(textChanged(QString)),
-            this, SLOT(wallpaperPathChanged(QString)));
+    _ui->wallpaperPath->setClearButtonEnabled(true);
+    _ui->wallpaperSelectButton->setIcon(QIcon::fromTheme(QStringLiteral("image-x-generic")));
+
+    connect(_ui->wallpaperSelectButton, &QToolButton::clicked, this, &Konsole::ColorSchemeEditor::selectWallpaper);
+    connect(_ui->wallpaperPath, &QLineEdit::textChanged, this, &Konsole::ColorSchemeEditor::wallpaperPathChanged);
 
     // color table
     _ui->colorTable->setColumnCount(3);
@@ -106,8 +125,7 @@ ColorSchemeEditor::ColorSchemeEditor(QWidget* aParent)
 
     _ui->colorTable->verticalHeader()->hide();
 
-    connect(_ui->colorTable , SIGNAL(itemClicked(QTableWidgetItem*)) , this ,
-            SLOT(editColorItem(QTableWidgetItem*)));
+    connect(_ui->colorTable , &QTableWidget::itemClicked , this , &Konsole::ColorSchemeEditor::editColorItem);
 
     // warning label when transparency is not available
     _ui->transparencyWarningWidget->setWordWrap(true);
@@ -136,9 +154,8 @@ void ColorSchemeEditor::editColorItem(QTableWidgetItem* item)
     }
 
     QColor color = item->background().color();
-    int result = KColorDialog::getColor(color);
-
-    if (result == KColorDialog::Accepted) {
+    color = QColorDialog::getColor();
+    if ( color.isValid() ) {
         item->setBackground(color);
 
         int colorSchemeRow = item->row();
@@ -156,7 +173,7 @@ void ColorSchemeEditor::editColorItem(QTableWidgetItem* item)
 }
 void ColorSchemeEditor::selectWallpaper()
 {
-    const KUrl url = KFileDialog::getImageOpenUrl(_ui->wallpaperPath->text(),
+    const QUrl url = KFileDialog::getImageOpenUrl(QUrl::fromUserInput(_ui->wallpaperPath->text()),
                      this,
                      i18nc("@action:button", "Select wallpaper image file"));
 
@@ -202,10 +219,10 @@ void ColorSchemeEditor::setup(const ColorScheme* scheme, bool isNewScheme)
     _colors = new ColorScheme(*scheme);
 
     if (_isNewScheme) {
-        setCaption(i18n("New Color Scheme"));
+        setWindowTitle(i18n("New Color Scheme"));
         setDescription(i18n("New Color Scheme"));
     } else {
-        setCaption(i18n("Edit Color Scheme"));
+        setWindowTitle(i18n("Edit Color Scheme"));
     }
 
     // setup description edit
@@ -268,4 +285,3 @@ void ColorSchemeEditor::saveColorScheme()
     emit colorSchemeSaveRequested(colorScheme(), _isNewScheme);
 }
 
-#include "ColorSchemeEditor.moc"
