@@ -29,7 +29,7 @@
 #include <QtCore/QTimer>
 
 // Konsole
-#include "konsole_export.h"
+#include "konsoleprivate_export.h"
 
 class QKeyEvent;
 
@@ -215,6 +215,8 @@ public:
      */
     bool programUsesMouse() const;
 
+    bool programBracketedPasteMode() const;
+
 public slots:
 
     /** Change the size of the emulation's image */
@@ -242,10 +244,8 @@ public slots:
      * Sends a string of characters to the foreground terminal process.
      *
      * @param string The characters to send.
-     * @param length Length of @p string or if set to a negative value, @p string will
-     * be treated as a null-terminated string and its length will be determined automatically.
      */
-    virtual void sendString(const char* string, int length = -1) = 0;
+    virtual void sendString(const QByteArray &string) = 0;
 
     /**
      * Processes an incoming stream of characters.  receiveData() decodes the incoming
@@ -268,9 +268,8 @@ signals:
      * standard input of the terminal.
      *
      * @param data The buffer of data ready to be sent
-     * @param len The length of @p data in bytes
      */
-    void sendData(const char* data, int len);
+    void sendData(const QByteArray& data);
 
     /**
      * Requests that the pty used by the terminal process
@@ -314,6 +313,8 @@ signals:
      */
     void programUsesMouseChanged(bool usesMouse);
 
+    void programBracketedPasteModeChanged(bool bracketedPasteMode);
+
     /**
      * Emitted when the contents of the screen image change.
      * The emulation buffers the updates from successive image changes,
@@ -474,8 +475,11 @@ private slots:
 
     void usesMouseChanged(bool usesMouse);
 
+    void bracketedPasteModeChanged(bool bracketedPasteMode);
+
 private:
     bool _usesMouse;
+    bool _bracketedPasteMode;
     QTimer _bulkTimer1;
     QTimer _bulkTimer2;
     bool _imageSizeInitialized;
