@@ -30,8 +30,7 @@
 // KDE
 #include <KConfig>
 #include <KConfigGroup>
-#include <KGlobal>
-#include <KDebug>
+#include <QDebug>
 
 // Konsole
 #include "Session.h"
@@ -45,18 +44,16 @@ SessionManager::SessionManager()
 {
     //map finished() signals from sessions
     _sessionMapper = new QSignalMapper(this);
-    connect(_sessionMapper , SIGNAL(mapped(QObject*)) , this ,
-            SLOT(sessionTerminated(QObject*)));
+    connect(_sessionMapper , static_cast<void(QSignalMapper::*)(QObject*)>(&QSignalMapper::mapped) , this , &Konsole::SessionManager::sessionTerminated);
 
     ProfileManager* profileMananger = ProfileManager::instance();
-    connect(profileMananger , SIGNAL(profileChanged(Profile::Ptr)) ,
-            this , SLOT(profileChanged(Profile::Ptr)));
+    connect(profileMananger , &Konsole::ProfileManager::profileChanged , this , &Konsole::SessionManager::profileChanged);
 }
 
 SessionManager::~SessionManager()
 {
     if (_sessions.count() > 0) {
-        kWarning() << "Konsole SessionManager destroyed with sessions still alive";
+        qWarning() << "Konsole SessionManager destroyed with sessions still alive";
         // ensure that the Session doesn't later try to call back and do things to the
         // SessionManager
         foreach(Session* session, _sessions) {
@@ -65,7 +62,7 @@ SessionManager::~SessionManager()
     }
 }
 
-K_GLOBAL_STATIC(SessionManager , theSessionManager)
+Q_GLOBAL_STATIC(SessionManager, theSessionManager)
 SessionManager* SessionManager::instance()
 {
     return theSessionManager;
@@ -99,13 +96,11 @@ Session* SessionManager::createSession(Profile::Ptr profile)
     Q_ASSERT(session);
     applyProfile(session, profile, false);
 
-    connect(session , SIGNAL(profileChangeCommandReceived(QString)) , this ,
-            SLOT(sessionProfileCommandReceived(QString)));
+    connect(session , &Konsole::Session::profileChangeCommandReceived , this , &Konsole::SessionManager::sessionProfileCommandReceived);
 
     //ask for notification when session dies
     _sessionMapper->setMapping(session, session);
-    connect(session , SIGNAL(finished()) , _sessionMapper ,
-            SLOT(map()));
+    connect(session , &Konsole::Session::finished , _sessionMapper , static_cast<void(QSignalMapper::*)()>(&QSignalMapper::map));
 
     //add session to active list
     _sessions << session;
@@ -187,7 +182,7 @@ void SessionManager::applyProfile(Session* session, const Profile::Ptr profile ,
     }
 
     if ( apply.shouldApply(Profile::TerminalColumns) ||
-         apply.shouldApply(Profile::TerminalRows) ) {
+            apply.shouldApply(Profile::TerminalRows) ) {
         const int columns = profile->property<int>(Profile::TerminalColumns);
         const int rows = profile->property<int>(Profile::TerminalRows);
         session->setPreferredSize(QSize(columns, rows));
@@ -330,6 +325,3 @@ Session* SessionManager::idToSession(int id)
     return 0;
 }
 
-
-#include "SessionManager.moc"
-
